#ifndef AlarmDialog_h
#define AlarmDialog_h

// $Id: AlarmDialog.h,v 1.14 2014/02/10 10:34:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file AlarmDialog.h
\brief alarm popup dialog
\author Hugo Pereira
\version $Revision: 1.14 $
\date $Date: 2014/02/10 10:34:30 $
*/

#include "Alarm.h"
#include "TransparentWidget.h"

namespace Clock
{
    //! alarm popup dialog
    class AlarmDialog: public Transparency::TransparentWidget
    {

        Q_OBJECT

        public:

        //! constructor
        AlarmDialog( QWidget* parent, const Alarm& alarm );

        //! destructor
        virtual ~AlarmDialog( void )
        {}

        Q_SIGNALS:

        //! emmitted to repeat alarm signal
        void repeat( const Alarm& );

        //! emmitted to stop alarm signal
        void closed( const Alarm& );

        protected:

        //! mouse press event [overloaded]
        virtual void mousePressEvent( QMouseEvent* );

        //! mouse press event [overloaded]
        virtual void mouseReleaseEvent( QMouseEvent *);

        //! mouse move event [overloaded]
        virtual void mouseMoveEvent( QMouseEvent* );

        //! paint event
        virtual void _paint( QPaintDevice&, const QRect& );

        //! render widget
        void _render( QPaintDevice&, QWidget&, const QRect& );

        //! current pressed button
        void _setButton( Qt::MouseButton button )
        { button_ = button; }

        //! current pressed button
        Qt::MouseButton _button( void ) const
        { return button_; }

        protected Q_SLOTS:

        //! close
        void _close( void )
        {
            emit closed( alarm_ );
            Transparency::TransparentWidget::close();
        }

        //! repeat
        void _repeat( void )
        {
            emit repeat( alarm_ );
            close();
        }

        private:

        //! use svg
        bool useSvg_;

        //! alarm
        const Alarm& alarm_;

        //! click position
        QPoint clickPosition_;

        //! button state
        Qt::MouseButton button_;

    };

};

#endif
