// $Id: EditDaysDialog.cpp,v 1.7 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "EditDaysDialog.h"
#include "EditDaysDialog.moc"
#include "Debug.h"

namespace Clock
{

    //_______________________________________________________________________
    EditDaysDialog::EditDaysDialog( QWidget* parent ):
        CustomDialog( parent )
    {

        Debug::Throw( "EditDaysDialog::EditDaysDialog.\n" );
        setWindowTitle( tr( "Alarm Days Selection - Clock" ) );
        setOptionName( "EDIT_DAY_DIALOG" );

        QHBoxLayout *hLayout( new QHBoxLayout() );
        hLayout->setMargin(0);
        hLayout->setSpacing(0);
        mainLayout().addLayout( hLayout );

        hLayout->addStretch( 1 );

        QVBoxLayout *vLayout( new QVBoxLayout() );
        vLayout->setMargin(0);
        vLayout->setSpacing(5);
        hLayout->addLayout( vLayout );
        hLayout->addStretch( 1 );

        for( int i=1; i<8; ++i )
        {
            QCheckBox* checkBox( new QCheckBox( QDate::longDayName( i ), this ) );
            vLayout->addWidget( checkBox );
            checkBoxes_ << checkBox;
        }

    }

    //_______________________________________________________________________
    void EditDaysDialog::setDays( unsigned int days )
    {
        for( unsigned int i=0; i<7; i++ )
        { checkBoxes_[i]->setChecked( days&(1<<(i+1)) ); }
    }

    //_______________________________________________________________________
    unsigned int EditDaysDialog::days( void ) const
    {
        unsigned int out( 0 );
        for( unsigned int i=0; i<7; i++ )
        { if( checkBoxes_[i]->isChecked() ) out |= (1<<(i+1)); }

        return out;
    }

}
