// $Id: CpuMonitor.cpp,v 1.4 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CpuMonitor.h"
#include "CpuMonitor.moc"
#include "Debug.h"
#include "Singleton.h"
#include "XmlOptions.h"

namespace Cpu
{

    //_____________________________________________
    CpuMonitor::CpuMonitor( QObject* parent ):
        QObject( parent ),
        Counter( "Cpu::CpuMonitor" ),
        cpuMenu_( 0 ),
        device_( "cpu" )
    {

        // cpu menu
        cpuMenu_ = new CpuMenu();
        connect( cpuMenu_, SIGNAL(deviceSelected(QString)), SLOT(_selectDevice(QString)) );
        cpuMenu_->setDevice( device_ );

        connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
        _updateConfiguration();

    }

    //______________________________________________________________________
    void CpuMonitor::_selectDevice( QString device )
    {
        device_ = device;
        XmlOptions::get().set( "CPU_NAME", device_ );
    }

    //__________________________________________________________
    void CpuMonitor::_updateConfiguration( void )
    {
        Debug::Throw( "Cpu::CpuMonitor::_updateConfiguration.\n" );

        // samples
        cpuLoad_.setSampleSize( XmlOptions::get().get<int>( "SAMPLES" ) );

        // device
        cpuMenu_->setDevice( device_ = XmlOptions::get().raw( "CPU_NAME" ) );

    }

}
