#ifndef CpuMonitor_h
#define CpuMonitor_h

// $Id: CpuMonitor.h,v 1.4 2014/02/10 11:08:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CpuLoad.h"
#include "CpuMenu.h"
#include "Counter.h"

#include <QObject>

namespace Cpu
{

    class CpuMonitor: public QObject, public Counter
    {


        //! Qt meta object functions
        Q_OBJECT

        public:

        //! constructor
        CpuMonitor( QObject* = 0 );

        //! destructor
        virtual ~CpuMonitor( void )
        {}

        //!@name accessors
        //@{

        //! menu
        CpuMenu& menu( void ) const
        { return *cpuMenu_; }

        //! device
        const QString& device( void ) const
        { return device_; }

        // network data
        CpuLoad::DataList data( void ) const
        { return cpuLoad_.data( device_ ); }

        //@}

        //!@name modifiers
        //@{

        //! update
        void update( void )
        { cpuLoad_.update(); }

        //! data size
        void setDataSize( int value )
        { cpuLoad_.setDataSize( value ); }

        //@}

        protected Q_SLOTS:

        //! device
        void _selectDevice( QString );

        private Q_SLOTS:

        //! configuration
        void _updateConfiguration( void );

        private:

        //! popup menu for cpu name
        CpuMenu* cpuMenu_;

        //! cpu load probe
        CpuLoad cpuLoad_;

        //! cpu name to display
        QString device_;

    };

}

#endif
