#ifndef Data_h
#define Data_h

// $Id: Data.h,v 1.8 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QTextStream>
#include "Counter.h"

namespace Disk {

  //! disk load data
  class Data: public Counter
  {

    public:

    //! data type
    enum Type
    {

      Write = 1<<0,
      Read = 1<<1,
      All = Write|Read

    };

    Q_DECLARE_FLAGS( Types, Type );

    //! constructor
    Data( unsigned long read = 0, unsigned long write = 0 ):
        Counter("Data"),
        read_( read ),
        write_( write ),
        time_( 0 ),
        valid_( false )
    {}

    //! difference between two points
    Data operator - ( const Data& data ) const
    {
      Data out( *this );
      out.read_  = read_ - data.read_;
      out.write_   = write_ - data.write_;
      out.time_       = time_ - data.time_;
      out.valid_ = ( valid_ && data.valid_ && out.time_ > 0 );
      return out;
    }

    //! write blocks
    void setRead( int value )
    { read_ = value; }

    //! write blocks
    int read( void ) const
    { return read_; }

    //! write blocks
    void setWrite( int value )
    { write_ = value; }

    //! write blocks
    int write( void ) const
    { return write_; }

    //! time
    void setTime( int time )
    { time_ = time; }

    //! time
    int time( void ) const
    { return time_; }

    //! validity
    void setValid( bool value )
    { valid_ = value; }

    //! validity
    bool valid( void ) const
    { return valid_; }

    //! sum
    long long int sum( Types type ) const
    {
      long long int out( 0 );
      if( type & Read ) out += read();
      if( type & Write ) out += write();
      return out;
    }

    private:

    //! write request
    int read_;

    //! read blocks
    int write_;

    //! measurement time
    int time_;

    //! true if current data are valid
    bool valid_;

    //! load from stream
    friend QTextStream& operator << (QTextStream& out, const Data& data)
    {
      out << "(" << data.read_ << "," << data.write_ << ") valid=" << data.valid_;
      return out;
    }

  };

}

Q_DECLARE_OPERATORS_FOR_FLAGS( Disk::Data::Types );

#endif
