#ifndef DataSamples_h
#define DataSamples_h

// $Id: DataSamples.h,v 1.9 2014/02/10 11:08:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Data.h"

#include <QList>

namespace Disk
{

    //! data samples container
    class DataSamples
    {

        public:

        //! shortcut for data list
        typedef QList< Data > DataList;

        //! construtor
        DataSamples( int sampleSize = 0, int dataSize = 0 ):
            sampleSize_( sampleSize ),
            dataSize_( dataSize )
        { }

        //! destructor
        ~DataSamples( void )
        {}

        //! set sample size
        void setSampleSize( const unsigned int sampleSize );

        //! set data point size
        void setDataSize( const unsigned int dataSize );

        //! retrieve data
        const DataList& data( void ) const
        { return dataList_; }

        //! add a data point
        void add( const Data& data );

        private:

        //! list of cpu load measurement
        DataList sampleList_;

        //! list of cpu load differences
        DataList dataList_;

        //! number of samples to be averaged to make the data points
        int sampleSize_;

        //! number of data point to store
        int dataSize_;

    };
};

#endif
