#ifndef ApplicationData_h
#define ApplicationData_h

// $Id: ApplicationData.h,v 1.13 2014/02/10 11:08:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QIcon>
#include <QRect>
#include <QString>
#include <QTextStream>

//__________________________________
class ApplicationData: public Counter
{
    public:

    //! used when LogEntry keyword is not defined
    static const QString MimeType;

    //! constructor
    ApplicationData( const QString& name  = "GENERIC_APPLICATION" ):
        Counter( "ApplicationData" ),
        name_( name ),
        order_( -1 )
    {}

    //! equal to
    bool operator == ( const ApplicationData& other ) const
    { return name() == other.name(); }

    //! less than
    bool operator < ( const ApplicationData& other ) const
    { return name() < other.name(); }

    //!@name accessors
    //@{

    //! name
    const QString& name( void ) const
    { return name_; }

    //! icon
    const QIcon& icon( void ) const
    { return icon_; }

    //! geometry
    const QRect& geometry( void ) const
    { return geometry_; }

    //! order
    int order( void ) const
    { return order_; }

    //!@}

    //!@name modifiers
    //@{

    //! name
    void setName( const QString& name )
    { name_ = name; }

    //! icon
    void setIcon( const QIcon& icon )
    { icon_ = icon; }

    //! geometry
    void setGeometry( const QRect& geometry )
    { geometry_ = geometry; }

    //! order
    void setOrder( int order )
    { order_ = order; }

    //@}

    //! sort horizontally
    class HorizontalFTor
    {
        public:

        //! predicate
        bool operator() ( const ApplicationData& first, const ApplicationData& second ) const
        {
            if( first.order() != second.order() ) return first.order() < second.order();
            else if( first.geometry().left() != second.geometry().left() ) return first.geometry().left() < second.geometry().left();
            else return first.geometry().top() < second.geometry().top();
        }

    };

    //! sort horizontally
    class VerticalFTor
    {
        public:

        //! predicate
        bool operator() ( const ApplicationData& first, const ApplicationData& second ) const
        {
            if( first.order() != second.order() ) return first.order() < second.order();
            else if( first.geometry().top() != second.geometry().top() ) return first.geometry().top() < second.geometry().top();
            else return first.geometry().left() < second.geometry().left();
        }

    };

    private:

    //! name
    QString name_;

    //! icon
    QIcon icon_;

    //! geometry
    QRect geometry_;

    //! order (used to layout multiple applications
    int order_;

    //! streamer
    friend QTextStream& operator << ( QTextStream &out, const ApplicationData& data )
    {
        out
            << "name: " << data.name()
            << " geometry:"
            << " (" << data.geometry().topLeft().x() << "," << data.geometry().topLeft().y() << ")"
            << " (" << data.geometry().width() << "," << data.geometry().height() << ")"
            << " order: " << data.order();
        return out;
    }

};

#endif
