
// $Id: ApplicationDataDialog.cpp,v 1.8 2013/11/13 13:52:15 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationDataDialog.h"
#include "ApplicationDataDialog.moc"
#include "GridLayout.h"

#include <QLabel>

//_____________________________________________________
ApplicationDataDialog::ApplicationDataDialog( QWidget* parent, ApplicationData data ):
    CustomDialog( parent, OkButton|CancelButton|Separator ),
    data_( data )
{

    setWindowTitle( "Application Geometry - Transparency-settings" );
    setOptionName( "APPLICATION_DATA_DIALOG" );

    mainLayout().addWidget( new QLabel( QString( tr( "name: %1" ) ).arg( data.name() ), this ) );

    GridLayout* gridLayout = new GridLayout();
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    gridLayout->setMaxCount( 4 );
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    mainLayout().addLayout( gridLayout );

    QLabel* label;
    gridLayout->addWidget( label = new QLabel( tr( "Position:" ) ) );
    gridLayout->addWidget( xSpinBox_ = new QSpinBox( this ) );
    xSpinBox_->setSuffix( tr( "px" ) );
    xSpinBox_->setMinimum( 0 );
    xSpinBox_->setMaximum( 5096 );
    xSpinBox_->setValue( data.geometry().left() );
    label->setBuddy( xSpinBox_ );

    gridLayout->addWidget( label = new QLabel( "x" ) );
    gridLayout->addWidget( ySpinBox_ = new QSpinBox( this ) );
    ySpinBox_->setSuffix( tr( "px" ) );
    ySpinBox_->setMinimum( 0 );
    ySpinBox_->setMaximum( 5096 );
    ySpinBox_->setValue( data.geometry().top() );
    label->setBuddy( ySpinBox_ );

    gridLayout->addWidget( label = new QLabel( tr( "Size:" ) ) );
    gridLayout->addWidget( wSpinBox_ = new QSpinBox( this ) );
    wSpinBox_->setSuffix( tr( "px" ) );
    wSpinBox_->setMinimum( 0 );
    wSpinBox_->setMaximum( 5096 );
    wSpinBox_->setValue( data.geometry().width() );
    label->setBuddy( wSpinBox_ );

    gridLayout->addWidget( label = new QLabel( "x") );
    gridLayout->addWidget( hSpinBox_ = new QSpinBox( this ) );
    hSpinBox_->setSuffix( tr( "px" ) );
    hSpinBox_->setMinimum( 0 );
    hSpinBox_->setMaximum( 5096 );
    hSpinBox_->setValue( data.geometry().height() );
    label->setBuddy( hSpinBox_ );

    gridLayout->setColumnStretch( 0, 1 );
    gridLayout->setColumnStretch( 2, 0 );

}

//______________________________________________________________
ApplicationData ApplicationDataDialog::data( void ) const
{
    ApplicationData out( data_ );
    out.setGeometry( QRect(
        QPoint( xSpinBox_->value(), ySpinBox_->value() ),
        QSize( wSpinBox_->value(), hSpinBox_->value() ) ) );
    return out;
}
