// $Id: HistogramWidget.cpp,v 1.35 2014/02/10 10:34:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "HistogramWidget.h"
#include "HistogramWidget.moc"

#include "BaseContextMenu.h"
#include "Effects.h"
#include "QtUtil.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QApplication>

//__________________________________________________________
HistogramWidget::HistogramWidget( QWidget *parent ):
    MainWindow( parent ),
    hostName_( Util::host( true ) )
{

    Debug::Throw( "HistogramWidget::HistogramWidget.\n" );
    setWindowTitle( tr( "Histogram Load" ) );

    _installActions();
    _updateConfiguration();

}

//______________________________________________________________________
void HistogramWidget::_installContextMenuActions( BaseContextMenu* menu )
{
    Debug::Throw( "SummaryWidget::_installContextMenuActions.\n" );

    // create parent menu
    MainWindow::_installContextMenuActions( menu );

    // actions
    menu->insertSeparator( &_menuSeparator() );
    menu->insertAction( &_menuSeparator(), showLoadAction_ );
    menu->insertAction( &_menuSeparator(), showHostAction_ );

}

//__________________________________________________________
void HistogramWidget::_updateConfiguration( void )
{
    Debug::Throw( "HistogramWidget::_updateConfiguration.\n" );

    // actions
    _showHostAction().setChecked( XmlOptions::get().get<bool>( "SHOW_HOST" ) );
    _showLoadAction().setChecked( XmlOptions::get().get<bool>( "SHOW_LOAD" ) );

    // base class update
    MainWindow::_updateConfiguration();
    _updateTimer().start( _refresh()*1000, this );

    update();
    Debug::Throw( "HistogramWidget::_updateConfiguration - done.\n" );

}

//________________________________________________
void HistogramWidget::_toggleShowHost( bool state )
{
    XmlOptions::get().set<bool>( "SHOW_HOST", _showHostAction().isChecked() );
    update();
}

//________________________________________________
void HistogramWidget::_toggleShowLoad( bool state )
{
    XmlOptions::get().set<bool>( "SHOW_LOAD", _showLoadAction().isChecked() );
    update();
}

//______________________________________________________________________
void HistogramWidget::_installActions( void )
{

    Debug::Throw( "HistogramWidget::_installActions.\n" );

    // additional flags
    addAction( showLoadAction_ = new QAction( tr( "Show Load" ), this ) );
    showLoadAction_->setCheckable( true );
    showLoadAction_->setChecked( false );
    connect( showLoadAction_, SIGNAL(toggled(bool)), SLOT(_toggleShowLoad(bool)) );

    addAction( showHostAction_ = new QAction( tr( "Show Hostname" ), this ) );
    showHostAction_->setCheckable( true );
    showHostAction_->setChecked( false );
    connect( showHostAction_, SIGNAL(toggled(bool)), SLOT(_toggleShowHost(bool)) );

}

//_________________________________________________________
void HistogramWidget::_paintHost( QPainter& painter, QRect& rect )
{

    Debug::Throw( "HistogramWidget::_paintHost.\n" );

    // save painter and update
    if( !( _showHostAction().isChecked() && _showHostAction().isEnabled() ) ) return;

    QPixmap pixmap( size() );
    pixmap.fill( Qt::transparent );
    {
        QPainter painter( &pixmap );
        painter.setPen( foregroundColor() );
        painter.drawText( rect, Qt::AlignHCenter|Qt::AlignBottom, _hostName() );
    }

    if( shadowOffset() > 0 && shadowColor().isValid() )
    {
        QImage image( pixmap.toImage() );
        Transparency::Effects::shadowBlur(image, shadowOffset(), shadowColor() );
        painter.drawImage( this->rect().topLeft(), image);
    }

    painter.drawPixmap( this->rect().topLeft(), pixmap );


    return;

}

//_________________________________________________________
void HistogramWidget::_paintText( QPainter& painter, const QString& value, QRect& rect )
{

    // save painter and update
    QPixmap pixmap( size() );
    pixmap.fill( Qt::transparent );
    {
        QPainter painter( &pixmap );
        painter.setPen( foregroundColor() );

        QRect boundingRect;
        painter.drawText( rect, Qt::AlignHCenter|Qt::AlignBottom, value, &boundingRect );
        rect.setBottom( boundingRect.top() );
    }

    if( shadowOffset() )
    {
        QImage image( pixmap.toImage() );
        Transparency::Effects::shadowBlur(image, 2, shadowColor() );
        painter.drawImage( this->rect().topLeft(), image);
    }

    painter.drawPixmap( this->rect().topLeft(), pixmap );


    return;

}
