/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseIconNames.h"
#include "Debug.h"
#include "IconEngine.h"
#include "NetworkLoad.h"
#include "NetworkMenu.h"
#include "NetworkMenu.moc"
#include "XmlOptions.h"

namespace Network
{
    //_____________________________________________________
    NetworkMenu::NetworkMenu( const QString& name, QWidget* parent ):
        QMenu( name, parent ),
        Counter( "NetworkMenu" ),
        isAutomatic_( false ),
        automaticAction_( 0L )
    {

        Debug::Throw( "NetworkMenu::NetworkMenu.\n" );

        connect( this, SIGNAL(triggered(QAction*)), SLOT(_select(QAction*)) );
        connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );

        actionGroup_ = new QActionGroup( this );
        actionGroup_->setExclusive( true );

    }

    //_____________________________________________________
    void NetworkMenu::_select( QAction* action )
    {

        Debug::Throw( "NetworkMenu::_select.\n" );
        if( action == automaticAction_ )
        {

            Debug::Throw( "NetworkMenu::_select - automatic.\n" );
            isAutomatic_ = true;
            emit automaticDeviceSelected();

        } else {

            ActionMap::const_iterator iter( actions_.find( action ) );
            if( iter != actions_.end() )
            {
                isAutomatic_ = false;
                device_ = iter.value();
                Debug::Throw() << "NetworkMenu::_select - device: " << device_ << endl;
                emit deviceSelected( device_ );
            }

        }

        return;
    }

    //_____________________________________________________
    void NetworkMenu::_update( void )
    {
        Debug::Throw( "NetworkMenu::_update.\n" );

        // clear
        clear();
        actions_.clear();

        NetworkLoad load;
        load.update();

        NetworkLoad::DeviceSet devices( load.devices() );
        NetworkLoad::DeviceSet connectedDevices( load.connectedDevices() );
        if( devices.empty() ) devices.insert( device_ );
        for( NetworkLoad::DeviceSet::const_iterator iter = devices.begin(); iter != devices.end(); ++iter )
        {
            QAction* action = addAction( *iter );
            if( connectedDevices.find( *iter ) != connectedDevices.end() )
            { action->setIcon( IconEngine::get( IconNames::DialogAccept ) ); }

            actionGroup_->addAction( action );
            action->setCheckable( true );
            action->setChecked( device_ == *iter && !isAutomatic_ );

            actions_.insert( action, *iter );

        }

        // add automatic action
        addSeparator();
        automaticAction_ = addAction( tr( "Automatic" ) );
        actionGroup_->addAction( automaticAction_ );
        automaticAction_->setCheckable( true );
        automaticAction_->setChecked( isAutomatic_ );

        return;

    }
}
