#ifndef TemperatureWidget_h
#define TemperatureWidget_h

// $Id: TemperatureWidget.h,v 1.21 2014/02/24 21:37:23 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TemperatureMonitor.h"
#include "HistogramWidget.h"

#include <QAction>
#include <QPainter>
#include <QBasicTimer>
#include <QTimerEvent>

//! temperature widgets
namespace Temperature
{

    //! transparent temperature load widget
    class TemperatureWidget : public HistogramWidget
    {

        //! Qt meta object functions
        Q_OBJECT

        public:

        //! constructor
        TemperatureWidget( QWidget* = 0 );

        //! destructor
        virtual ~TemperatureWidget( void )
        {}

        protected:

        //!@name event handlers
        //@{

        //! timer
        void timerEvent( QTimerEvent* );

        //! paint event [overloaded]
        void _paint( QPaintDevice&, const QRect& );

        //! resize event [overloaded]
        void resizeEvent( QResizeEvent* );

        //@}

        protected Q_SLOTS:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //! opend configuration dialog
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! toggle inverse colors
        virtual void _toggleInverseColors( bool );

        protected:

        //! scale factor
        double _getScale( const Temperature::DataList& ) const;

        //! draw load text
        void _paintLoad( QPainter&, QRect& );

        //! set default colors
        void _setDefaultColors( void );

        private:

        //! monitor
        TemperatureMonitor temperatureMonitor_;

        //! popup menu for probe name
        QAction* temperatureMenuAction_;

        //!@name properties
        //@{

        //! foreground color for user bar
        Color temperatureColor_;

        //@}

    };
}

#endif
